#!/usr/bin/env python

import scipy, pylab
from scipy import pi

r2d = scipy.rad2deg

def main():
    Npts = 4
    phi = 0.1*(2*(scipy.rand(Npts))-1)
    phi0 = 0.1*(2*scipy.rand()-1)
    f = 100.0
    fs = 1000.0
    t = scipy.linspace(0, (Npts-1)/fs, Npts)
    
    z = scipy.cos(2*pi*f*t + phi + phi0) + \
        1j*scipy.sin(2*pi*f*t + phi + phi0)
    theta = scipy.angle(z)
    mag = abs(z)

    fig = pylab.figure(1, figsize=(12,10), facecolor='w')
    sp = fig.add_subplot(1,1,1, polar='true')
    sp.plot(theta, mag, 'bo', ms=20)
    sp.set_ylim([0, 1.1])
    for i in xrange(Npts):
        sp.plot([0, theta[i]], [0, mag[i]], 'b-', linewidth=2)

        sp.text(theta[i]-0.15, mag[i], "Phase = {0:.4f}".format(r2d(theta[i])),
                bbox=dict(facecolor='white', alpha=0.5),
                horizontalalignment='center', fontsize=20, fontweight='bold')

    rad_per_sec  = f*2*pi
    rad_per_samp = r2d(rad_per_sec*(1/fs))
    info = "Frequency = {0:.0f} Hz\n".format(f) + \
        "Time per Sample = {0:.1f} ms\n".format(1000/fs) + \
        "Radians per Sample = {0:.1f}".format(rad_per_samp)
    sp.text(9.8*pi/12, 1.8, info,
            horizontalalignment='left',
            fontsize=18)

    pylab.savefig('../figs/complex_numbers.eps', dpi=300,
                  format='eps');
    pylab.show()

if __name__ == "__main__":
    main()
